==> sdlskk-0.1.tar.gz: sdlskk-0.1/sdlskk_internal.h <==
#ifndef SDLSKK_INTERNAL_H
#define SDLSKK_INTERNAL_H

#include "sdlskk.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define DICT_TABLE_SIZE 10297

#define CTRL(x) ((x)-'a'+1)

typedef struct SDLSKK_XStr SDLSKK_XStr;
struct SDLSKK_XStr {
  SDLSKK_Char* buf;
  int len;
  int max;
};

typedef struct SDLSKK_ListElement SDLSKK_ListElement;
struct SDLSKK_ListElement {
  SDLSKK_ListElement *next, *prev;
  SDLSKK_Char *val;
};

typedef struct SDLSKK_StrList SDLSKK_StrList;
struct SDLSKK_StrList {
  SDLSKK_ListElement *begin, *end;
};

typedef struct SDLSKK_HashElement SDLSKK_HashElement;
struct SDLSKK_HashElement {
  SDLSKK_HashElement *next;
  SDLSKK_Char *key;
  SDLSKK_StrList *vals;
};

typedef struct SDLSKK_Map SDLSKK_Map;
struct SDLSKK_Map {
  SDLSKK_HashElement **table;
  int table_size;
};

struct SDLSKK_Dictionary {
  SDLSKK_Map *map;
};

struct SDLSKK_DictionaryItem {
  SDLSKK_Dictionary *dict;
  SDLSKK_Char* hiragana;
  SDLSKK_StrList* kanji;
  SDLSKK_ListElement* cur;
};


enum SDLSKK_RomKanaSolveState {
  SDLSKK_RomKana_NoCandidate,
  SDLSKK_RomKana_SomeCandidates,
  SDLSKK_RomKana_OneCandidate,
  SDLSKK_RomKana_UnresolvedCandidate
};
typedef enum SDLSKK_RomKanaSolveState SDLSKK_RomKanaSolveState;

typedef struct SDLSKK_RomKanaElement SDLSKK_RomKanaElement;
struct SDLSKK_RomKanaElement{
  SDLSKK_RomKanaElement* next;
  SDLSKK_Char* key;
  SDLSKK_Char* next_state;
  SDLSKK_Char* hiragana;
  SDLSKK_Char* katakana;
};

struct SDLSKK_RomKanaRuleTable{
  SDLSKK_RomKanaElement *top;
};



struct SDLSKK_Context {
  SDLSKK_Dictionary *dict;
  SDLSKK_RomKanaRuleTable* rule_table;
  
  SDLSKK_XStr* str;
  int cursor_pos;
  
  SDLSKK_XStr* prefix;
  SDLSKK_XStr* henkan_key;
  int henkan_buf_pos;
  SDLSKK_Char okuri_char;
  SDLSKK_XStr* henkan_okurigana;

  SDLSKK_DictionaryItem* dict_item;

  int katakana_on;
  
  SDLSKK_XStr* display_str;
  SDLSKK_XStr* minibuffer_str;
  
  SDLSKK_Mode mode;
};

SDLSKK_Char* SDLSKK_Context_get_display_Str( SDLSKK_Context* context );
SDLSKK_Char* SDLSKK_Context_get_minibuffer_Str( SDLSKK_Context* context );
void SDLSKK_Context_get_henkan_XStr( SDLSKK_Context* context, SDLSKK_XStr* xstr );

void SDLSKK_RomKanaRuleTable_add( SDLSKK_RomKanaRuleTable* rule_table,
				  SDLSKK_Char* key,
				  SDLSKK_Char* next_state, 
				  SDLSKK_Char* hiragana,
				  SDLSKK_Char* katakana
				  );

SDLSKK_RomKanaSolveState SDLSKK_RomKanaRuleTable_get( SDLSKK_RomKanaRuleTable* rule_table,
						      SDLSKK_Char* prefix,
						      SDLSKK_RomKanaElement** candidate );

SDLSKK_DictionaryItem* SDLSKK_Dict_get( SDLSKK_Dictionary* dict,
					SDLSKK_Char *hiragana );
SDLSKK_Char* SDLSKK_DictItem_get_current( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_next( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_prev( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_reset( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_delete( SDLSKK_DictionaryItem* item );
int SDLSKK_DictItem_is_end( SDLSKK_DictionaryItem* item );
int SDLSKK_DictItem_is_begin( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_commit( SDLSKK_DictionaryItem* item );

SDLSKK_Char* SDLSKK_Str_new( SDLSKK_Char * str );
SDLSKK_Char* SDLSKK_Str_new2( char* str );
SDLSKK_Char SDLSKK_get_sc( unsigned char* line, int* pos );
SDLSKK_Char* SDLSKK_Str_insert_Char( SDLSKK_Char* str, int pos, SDLSKK_Char c, int max_buf );
SDLSKK_Char* SDLSKK_Str_insert_Str( SDLSKK_Char* str, int pos, SDLSKK_Char *istr, int max_buf );
SDLSKK_Char* SDLSKK_Str_delete_Char( SDLSKK_Char* str, int pos );
void SDLSKK_Str_clear( SDLSKK_Char* str );
SDLSKK_Char* SDLSKK_cstr_tokenize( char* line, char delimiter, int* pos );
void SDLSKK_Str_chop( SDLSKK_Char* str );
char* SDLSKK_Str_to_cstr( SDLSKK_Char* str, unsigned char* cstr, size_t size );
int SDLSKK_Str_len( SDLSKK_Char* str );
int SDLSKK_str_equal( SDLSKK_Char *str1, SDLSKK_Char *str2 );
SDLSKK_Char SDLSKK_latin_to_jisx0208_Char( SDLSKK_Char ch );
SDLSKK_Char SDLSKK_hiragana_to_katakana( SDLSKK_Char ch );
SDLSKK_Char SDLSKK_katakana_to_hiragana( SDLSKK_Char ch );
SDLSKK_Char* SDLSKK_Str_hiragana_to_katakana( SDLSKK_Char* str );
SDLSKK_Char* SDLSKK_Str_katakana_to_hiragana( SDLSKK_Char* str );

SDLSKK_XStr* SDLSKK_XStr_new1( SDLSKK_Char* str );
SDLSKK_XStr* SDLSKK_XStr_new2( SDLSKK_Char* str, int maxlen );
SDLSKK_XStr* SDLSKK_XStr_new3( char* str );
SDLSKK_XStr* SDLSKK_XStr_new4( char* str, int maxlen );
SDLSKK_XStr* SDLSKK_XStr_new5( SDLSKK_XStr* str );
void SDLSKK_XStr_delete( SDLSKK_XStr* str );
void SDLSKK_XStr_insert_Char( SDLSKK_XStr* str, int pos, SDLSKK_Char c );
void SDLSKK_XStr_insert_Str( SDLSKK_XStr* str, int pos, SDLSKK_Char *istr );
void SDLSKK_XStr_delete_Char( SDLSKK_XStr* str, int pos );
void SDLSKK_XStr_clear( SDLSKK_XStr* str );
void SDLSKK_XStr_concat_Str( SDLSKK_XStr* str1, SDLSKK_Char* str2 );
void SDLSKK_XStr_copy_Str( SDLSKK_XStr* str1, SDLSKK_Char* str2 );
void SDLSKK_XStr_slice_Str( SDLSKK_XStr* dest, SDLSKK_Char* src, int start, int end );

SDLSKK_StrList* SDLSKK_StrList_new( void );
SDLSKK_ListElement* SDLSKK_StrList_find( SDLSKK_StrList* list, SDLSKK_Char* val );
void SDLSKK_StrList_insert( SDLSKK_StrList* list, SDLSKK_ListElement *locate,
			    SDLSKK_Char* val );
void SDLSKK_StrList_push( SDLSKK_StrList* list, SDLSKK_Char* val );
void SDLSKK_StrList_shift( SDLSKK_StrList* list, SDLSKK_Char* val );
void SDLSKK_StrList_delete( SDLSKK_StrList* list );
void SDLSKK_StrList_delete_all( SDLSKK_StrList* list );

SDLSKK_Map* SDLSKK_Map_new( int table_size );
void SDLSKK_Map_set( SDLSKK_Map* map, SDLSKK_Char* key, SDLSKK_StrList* vals );
SDLSKK_StrList* SDLSKK_Map_get( SDLSKK_Map* map, SDLSKK_Char* key );
void SDLSKK_Map_delete( SDLSKK_Map* map );
void SDLSKK_Map_delete_all( SDLSKK_Map* map );

void SDLSKK_Char_to_char( SDLSKK_Char c, char *result );
#endif

==> sdlskk-0.2.tar.gz: sdlskk-0.2/sdlskk_internal.h <==
#ifndef SDLSKK_INTERNAL_H
#define SDLSKK_INTERNAL_H

#include "sdlskk.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define DICT_TABLE_SIZE 10297

#define CTRL(x) ((x)-'a'+1)

typedef struct SDLSKK_XStr SDLSKK_XStr;
struct SDLSKK_XStr {
  SDLSKK_Char* buf;
  int len;
  int max;
};

typedef struct SDLSKK_ListElement SDLSKK_ListElement;
struct SDLSKK_ListElement {
  SDLSKK_ListElement *next, *prev;
  SDLSKK_Char *val;
  int save;
};

typedef struct SDLSKK_StrList SDLSKK_StrList;
struct SDLSKK_StrList {
  SDLSKK_ListElement *begin, *end;
};

typedef struct SDLSKK_HashElement SDLSKK_HashElement;
struct SDLSKK_HashElement {
  SDLSKK_HashElement *next;
  SDLSKK_Char *key;
  SDLSKK_StrList *vals;
};

typedef struct SDLSKK_Map SDLSKK_Map;
struct SDLSKK_Map {
  SDLSKK_HashElement **table;
  int table_size;
};

struct SDLSKK_Dictionary {
  SDLSKK_Map *map;
};

struct SDLSKK_DictionaryItem {
  SDLSKK_Dictionary *dict;
  SDLSKK_Char* hiragana;
  SDLSKK_StrList* kanji;
  SDLSKK_ListElement* cur;
};


enum SDLSKK_RomKanaSolveState {
  SDLSKK_RomKana_NoCandidate,
  SDLSKK_RomKana_SomeCandidates,
  SDLSKK_RomKana_OneCandidate,
  SDLSKK_RomKana_UnresolvedCandidate
};
typedef enum SDLSKK_RomKanaSolveState SDLSKK_RomKanaSolveState;

typedef struct SDLSKK_RomKanaElement SDLSKK_RomKanaElement;
struct SDLSKK_RomKanaElement{
  SDLSKK_RomKanaElement* next;
  SDLSKK_Char* key;
  SDLSKK_Char* next_state;
  SDLSKK_Char* hiragana;
  SDLSKK_Char* katakana;
};

struct SDLSKK_RomKanaRuleTable{
  SDLSKK_RomKanaElement *top;
};



struct SDLSKK_Context {
  SDLSKK_Dictionary *dict;
  SDLSKK_RomKanaRuleTable* rule_table;
  
  SDLSKK_XStr* str;
  int cursor_pos;
  
  SDLSKK_XStr* prefix;
  SDLSKK_XStr* henkan_key;
  int henkan_buf_pos;
  SDLSKK_Char okuri_char;
  SDLSKK_XStr* henkan_okurigana;

  SDLSKK_DictionaryItem* dict_item;

  int katakana_on;
  
  SDLSKK_XStr* display_str;
  SDLSKK_XStr* minibuffer_str;
  
  SDLSKK_Mode mode;
};

SDLSKK_Char* SDLSKK_Context_get_display_Str( SDLSKK_Context* context );
SDLSKK_Char* SDLSKK_Context_get_minibuffer_Str( SDLSKK_Context* context );
void SDLSKK_Context_get_henkan_XStr( SDLSKK_Context* context, SDLSKK_XStr* xstr );

void SDLSKK_RomKanaRuleTable_add( SDLSKK_RomKanaRuleTable* rule_table,
				  SDLSKK_Char* key,
				  SDLSKK_Char* next_state, 
				  SDLSKK_Char* hiragana,
				  SDLSKK_Char* katakana
				  );

SDLSKK_RomKanaSolveState SDLSKK_RomKanaRuleTable_get( SDLSKK_RomKanaRuleTable* rule_table,
						      SDLSKK_Char* prefix,
						      SDLSKK_RomKanaElement** candidate );

SDLSKK_DictionaryItem* SDLSKK_Dict_get( SDLSKK_Dictionary* dict,
					SDLSKK_Char *hiragana );
SDLSKK_Char* SDLSKK_DictItem_get_current( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_next( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_prev( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_reset( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_delete( SDLSKK_DictionaryItem* item );
int SDLSKK_DictItem_is_end( SDLSKK_DictionaryItem* item );
int SDLSKK_DictItem_is_begin( SDLSKK_DictionaryItem* item );
void SDLSKK_DictItem_commit( SDLSKK_DictionaryItem* item );

SDLSKK_Char* SDLSKK_Str_new( SDLSKK_Char * str );
SDLSKK_Char* SDLSKK_Str_new2( char* str );
SDLSKK_Char SDLSKK_get_sc( unsigned char* line, int* pos );
SDLSKK_Char* SDLSKK_Str_insert_Char( SDLSKK_Char* str, int pos, SDLSKK_Char c, int max_buf );
SDLSKK_Char* SDLSKK_Str_insert_Str( SDLSKK_Char* str, int pos, SDLSKK_Char *istr, int max_buf );
SDLSKK_Char* SDLSKK_Str_delete_Char( SDLSKK_Char* str, int pos );
void SDLSKK_Str_clear( SDLSKK_Char* str );
SDLSKK_Char* SDLSKK_cstr_tokenize( char* line, char delimiter, int* pos );
void SDLSKK_Str_chop( SDLSKK_Char* str );
char* SDLSKK_Str_to_cstr( SDLSKK_Char* str, unsigned char* cstr, size_t size );
int SDLSKK_Str_len( SDLSKK_Char* str );
int SDLSKK_str_equal( SDLSKK_Char *str1, SDLSKK_Char *str2 );
SDLSKK_Char SDLSKK_latin_to_jisx0208_Char( SDLSKK_Char ch );
SDLSKK_Char SDLSKK_hiragana_to_katakana( SDLSKK_Char ch );
SDLSKK_Char SDLSKK_katakana_to_hiragana( SDLSKK_Char ch );
SDLSKK_Char* SDLSKK_Str_hiragana_to_katakana( SDLSKK_Char* str );
SDLSKK_Char* SDLSKK_Str_katakana_to_hiragana( SDLSKK_Char* str );

SDLSKK_XStr* SDLSKK_XStr_new1( SDLSKK_Char* str );
SDLSKK_XStr* SDLSKK_XStr_new2( SDLSKK_Char* str, int maxlen );
SDLSKK_XStr* SDLSKK_XStr_new3( char* str );
SDLSKK_XStr* SDLSKK_XStr_new4( char* str, int maxlen );
SDLSKK_XStr* SDLSKK_XStr_new5( SDLSKK_XStr* str );
void SDLSKK_XStr_delete( SDLSKK_XStr* str );
void SDLSKK_XStr_insert_Char( SDLSKK_XStr* str, int pos, SDLSKK_Char c );
void SDLSKK_XStr_insert_Str( SDLSKK_XStr* str, int pos, SDLSKK_Char *istr );
void SDLSKK_XStr_delete_Char( SDLSKK_XStr* str, int pos );
void SDLSKK_XStr_clear( SDLSKK_XStr* str );
void SDLSKK_XStr_concat_Str( SDLSKK_XStr* str1, SDLSKK_Char* str2 );
void SDLSKK_XStr_copy_Str( SDLSKK_XStr* str1, SDLSKK_Char* str2 );
void SDLSKK_XStr_slice_Str( SDLSKK_XStr* dest, SDLSKK_Char* src, int start, int end );

SDLSKK_StrList* SDLSKK_StrList_new( void );
SDLSKK_ListElement* SDLSKK_StrList_find( SDLSKK_StrList* list, SDLSKK_Char* val );
void SDLSKK_StrList_insert( SDLSKK_StrList* list, SDLSKK_ListElement *locate,
			    SDLSKK_Char* val, int save );
void SDLSKK_StrList_push( SDLSKK_StrList* list, SDLSKK_Char* val, int save );
void SDLSKK_StrList_shift( SDLSKK_StrList* list, SDLSKK_Char* val, int save );
void SDLSKK_StrList_delete( SDLSKK_StrList* list );
void SDLSKK_StrList_delete_all( SDLSKK_StrList* list );

SDLSKK_Map* SDLSKK_Map_new( int table_size );
void SDLSKK_Map_set( SDLSKK_Map* map, SDLSKK_Char* key, SDLSKK_StrList* vals );
SDLSKK_StrList* SDLSKK_Map_get( SDLSKK_Map* map, SDLSKK_Char* key );
void SDLSKK_Map_delete( SDLSKK_Map* map );
void SDLSKK_Map_delete_all( SDLSKK_Map* map );

void* SDLSKK_malloc( size_t size );
void* SDLSKK_realloc( void* ptr, size_t size );

void SDLSKK_Char_to_char( SDLSKK_Char c, char *result );
void print_Str( SDLSKK_Char* str );
#endif
